package com.xyzc.start.controller;

import com.xyzc.common.core.utils.Result;
import com.xyzc.start.domain.bo.HobbyBo;
import com.xyzc.start.domain.vo.BaseUserPhotoFolderVo;
import com.xyzc.start.domain.vo.BaseUserVo;
import com.xyzc.start.domain.vo.IndustryVo;
import com.xyzc.start.service.IUserInfoService;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 用户信息
 *
 * @author 杨兴卓
 */

@RestController
@RequiredArgsConstructor
@RequestMapping("userInfo")
public class UserInfoController {

    private final IUserInfoService userInfoService;

    /**
     * 登录用户获取用户信息
     */
    @GetMapping("/info")
    public Result<BaseUserVo> info() {
        BaseUserVo baseUserVo = userInfoService.queryInfo();

        return Result.ok(baseUserVo);
    }

    /**
     * 获取当前用户的燃料和会员卡信息
     */
    @GetMapping("/current")
    public Result<BaseUserVo> current() {
        BaseUserVo baseUserVo = userInfoService.queryCurrent();
        return Result.ok(baseUserVo);
    }

    /**
     * 用户选择喜好
     */
    @PostMapping("/hobby")
    public Result<Void> hobby(@RequestBody @Valid HobbyBo hobby) {
        userInfoService.saveHobby(hobby);

        return Result.ok();
    }


    /**
     * 获取所有行业
     *
     * @return
     */
    @GetMapping("/queryIndustryAll")
    public Result<List<IndustryVo>> queryIndustryAll() {
        List<IndustryVo> industryAll = userInfoService.getIndustryAll();
        return Result.ok(industryAll);
    }


}
