package com.xyzc.start.service.impl;

import com.xyzc.common.core.exception.ErrorCode;
import com.xyzc.common.core.exception.ServerException;
import com.xyzc.common.web.security.user.SecurityUser;
import com.xyzc.start.domain.bo.HobbyBo;
import com.xyzc.start.domain.vo.BaseUserMemberCardVo;
import com.xyzc.start.domain.vo.BaseUserPhotoFolderVo;
import com.xyzc.start.domain.vo.BaseUserVo;
import com.xyzc.start.domain.vo.IndustryVo;
import com.xyzc.start.mapper.BaseUserMapper;
import com.xyzc.start.mapper.BaseUserPhotoFolderMapper;
import com.xyzc.start.mapper.IndustryMapper;
import com.xyzc.start.service.IUserInfoService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.List;


@Service
@RequiredArgsConstructor
public class UserInfoServiceImpl implements IUserInfoService {

    private final BaseUserMapper baseUserMapper;
    private final IndustryMapper industryMapper;
    private final BaseUserPhotoFolderMapper photoFolderMapper;

    /**
     * 获取当前用户信息
     * @return
     */
    @Override
    public BaseUserVo queryCurrent() {
        BaseUserVo baseUser = baseUserMapper.queryCurrentInfo(SecurityUser.getUserId());
        return baseUser;
    }

    /**
     * 保存用户爱好
     * @param hobbyBo HobbyBo
     */
    @Override
    public void saveHobby(HobbyBo hobbyBo) {

        baseUserMapper.saveHobbys(SecurityUser.getUserId(), hobbyBo);
    }

    /**
     * 获取用户信息
     * @return
     */
    @Override
    public BaseUserVo queryInfo() {
        Long userId = SecurityUser.getUserId();
        BaseUserVo baseUserVo = baseUserMapper.selectVoById(userId);

        // TODO： 后续计算
        baseUserVo.setUseCount(108);
        baseUserVo.setAvatar("https://devimg.xiaoyizc.com/2024/08/01/d3411b7c32874513a193b02628c5bd1b.jpg");


        // 添加用户拥有的会员卡
        List<BaseUserMemberCardVo> memberCardVos = baseUserMapper.queryMyMemberCardByUserId(baseUserVo.getId());
        baseUserVo.setMemberCardVoList(memberCardVos);

        // 添加用户会员卡数量
        baseUserVo.setMemberCardCount(memberCardVos.size());


        return baseUserVo;
    }

    /**
     * 获取所有的行业
     * @return
     */
    @Override
    public List<IndustryVo> getIndustryAll() {
        return industryMapper.queryList(null);
    }

    /**
     * 根据 id获取用户图画
     * @param id Long
     * @return BaseUserPhotoFolderVo
     */
    @Override
    public BaseUserPhotoFolderVo queryPhotoById(Long id) {
        return photoFolderMapper.queryPhotoFolderById(SecurityUser.getUserId(), id);
    }

    /**
     * 获取用户画夹
     * @param id
     * @return
     */
    @Override
    public List<BaseUserPhotoFolderVo> photoFolder(Long id) {
        return photoFolderMapper.queryPhotoFolder(SecurityUser.getUserId(), id);
    }

    @Override
    public void deletePhoto(Long id) {
        //todo 记得后期删除图片
        Boolean flag = photoFolderMapper.deletePhotoById(SecurityUser.getUserId(), id);
        if(!flag) {
            throw new ServerException(ErrorCode.USER_DELETE_IMAGE_ERROR);
        }
    }

    @Override
    public void deletePhotos(List<Long> ids) {

    }
}
